@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::Commit;
 {
-  $Dist::Zilla::Plugin::Git::Commit::VERSION = '1.112510';
+  $Dist::Zilla::Plugin::Git::Commit::VERSION = '1.113220';
 }
 # ABSTRACT: commit dirty files
 
@@ -22,6 +22,7 @@ use Moose;
 use MooseX::Has::Sugar;
 use MooseX::Types::Moose qw{ Str };
 use Path::Class::Dir ();
+use Cwd;
 
 use String::Formatter method_stringf => {
   -as => '_format_string',
@@ -40,7 +41,7 @@ use String::Formatter method_stringf => {
 
 with 'Dist::Zilla::Role::AfterRelease';
 with 'Dist::Zilla::Role::Git::DirtyFiles';
-
+with 'Dist::Zilla::Role::Git::Repo';
 
 # -- attributes
 
@@ -54,7 +55,8 @@ sub mvp_multivalue_args { qw( add_files_in ) }
 
 sub after_release {
     my $self = shift;
-    my $git  = Git::Wrapper->new('.');
+
+    my $git  = Git::Wrapper->new( $self->repo_root );
     my @output;
 
     # check if there are dirty files that need to be committed.
@@ -80,7 +82,7 @@ sub after_release {
     return unless @output;    
 
     # write commit message in a temp file
-    my ($fh, $filename) = tempfile( 'DZP-git.XXXX', UNLINK => 1 );
+    my ($fh, $filename) = tempfile( getcwd . '/DZP-git.XXXX', UNLINK => 0 );
     print $fh $self->get_commit_message;
     close $fh;
 
@@ -129,7 +131,7 @@ Dist::Zilla::Plugin::Git::Commit - commit dirty files
 
 =head1 VERSION
 
-version 1.112510
+version 1.113220
 
 =head1 SYNOPSIS
 
