@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::Tag;
 {
-  $Dist::Zilla::Plugin::Git::Tag::VERSION = '1.112510';
+  $Dist::Zilla::Plugin::Git::Tag::VERSION = '1.113220';
 }
 # ABSTRACT: tag the new version
 
@@ -36,6 +36,7 @@ use String::Formatter method_stringf => {
 
 with 'Dist::Zilla::Role::BeforeRelease';
 with 'Dist::Zilla::Role::AfterRelease';
+with 'Dist::Zilla::Role::Git::Repo';
 
 
 # -- attributes
@@ -60,7 +61,8 @@ sub _build_tag
 
 sub before_release {
     my $self = shift;
-    my $git  = Git::Wrapper->new('.');
+
+    my $git  = Git::Wrapper->new( $self->repo_root );
 
     # Make sure a tag with the new version doesn't exist yet:
     my $tag = $self->tag;
@@ -70,7 +72,7 @@ sub before_release {
 
 sub after_release {
     my $self = shift;
-    my $git  = Git::Wrapper->new('.');
+    my $git  = Git::Wrapper->new( $self->repo_root );
 
     my @opts;
     push @opts, ( '-m' => _format_tag($self->tag_message, $self) )
@@ -97,7 +99,7 @@ Dist::Zilla::Plugin::Git::Tag - tag the new version
 
 =head1 VERSION
 
-version 1.112510
+version 1.113220
 
 =head1 SYNOPSIS
 
