@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Role::Git::DirtyFiles;
 {
-  $Dist::Zilla::Role::Git::DirtyFiles::VERSION = '1.112510';
+  $Dist::Zilla::Role::Git::DirtyFiles::VERSION = '1.113220';
 }
 # ABSTRACT: provide the allow_dirty & changelog attributes
 
@@ -21,6 +21,7 @@ use Moose::Autobox;
 use MooseX::Has::Sugar;
 use MooseX::Types::Moose qw{ ArrayRef Str };
 
+use List::Util 'first';
 
 # -- attributes
 
@@ -50,10 +51,16 @@ sub list_dirty_files
 {
   my ($self, $git, $listAllowed) = @_;
 
-  my %allowed = map { $_ => 1 } $self->allow_dirty->flatten;
+  my @allowed = map { qr/${_}$/ } $self->allow_dirty->flatten;
 
-  return grep { $allowed{$_} ? $listAllowed : !$listAllowed }
-      $git->ls_files( { modified=>1, deleted=>1 } );
+  return grep { 
+      my $file = $_; 
+      if ( first { $file =~ $_ } @allowed ) { 
+          $listAllowed 
+      } else { 
+          !$listAllowed 
+      } 
+  } $git->ls_files( { modified=>1, deleted=>1 } );
 } # end list_dirty_files
 
 
@@ -70,7 +77,7 @@ Dist::Zilla::Role::Git::DirtyFiles - provide the allow_dirty & changelog attribu
 
 =head1 VERSION
 
-version 1.112510
+version 1.113220
 
 =head1 DESCRIPTION
 
